@@ -5,9 +5,9 @@ if __name__ == '__main__':
 import sys
 import rich
 
-from shell.shell import Function, Shell, has_input, set_cli_args, sh_to_py, main
-from io_util import has_output
-import cli
+from mash.shell.shell import Function, Shell, has_input, set_cli_args, sh_to_py, main
+from mash.io_util import has_output
+from mash import cli
 
 
 def f(x: int): return x
